# Seedpod

This project is a rkt pod dedicated to private torrenting. It supports PIA with openvpn to be in a constant VPN connection.  When the VPN becomes disconnected for whatever reason, the torrenting stops, in fact the torrent is only allowed to seed/leech if it is inside of the VPN tunnel.

## Quickstart
To quickly get seedpod up and running you will need a PIA openvpn config file (or use default) and your access creds.
In theory this will support any VPN that uses openvpn and a basic auth file.

### Docker
The quickest way to get going to by pulling the docker image from dockerhub. The image name is `unixvoid/seedpod` and can be found [here](https://hub.docker.com/r/unixvoid/seedpod/).
You will need (at minimum) a PIA credentials file that we will be linking into the container. This credentials file will allow openvpn to run in the background of the image so all information going in and out will be private.

#### Configuring
- **Credentials**: you will need to link in a credentials file (see below for the recommended run command) named `creds.x` into `/openvpn/` in the container. The formatting for the credentials file is simple, first line is the username, second is the password.  Example:  
```
p1122334
xyzPASSWORDxyz
```

- **Config**: you can optionally supply an openvpn configuration file if you are using a VPN that support openvpn. Just place the configuration file (named `config.ovpn`) into the container at `/openvpn/`.

#### Running
```
sudo docker run \
	-d \
	--name seedpod \
	--cap-add=NET_ADMIN \
	--cap-add=NET_RAW \
	--device=/dev/net/tun \
	--dns=8.8.8.8 \
	-p 9091:9091 \
	-v /home/user/seedpod/deps/creds.x:/openvpn/creds.x:ro \
	-v /home/user/transmission/downloads:/transmission/downloads:rw \
	-v /home/user/transmission/incomplete:/transmission/incomplete:rw \
      unixvoid/seedpod
```
  Please note the use of `--cap-add=NET_ADMIN`, `--cap-add=NET_RAW`, `--device=/dev/net/tun`. These are needed by the image to create the VPN connection properly. Without these arguments the container will not be able to connect to the VPN.

#### Accessing
Once you have started the container is accessable on port 9091 with the following credentials:
- user: `admin`
- pass: `password`

## Building from source
- **Config**: place your config in `deps/` full path to the file will be `deps/config.ovpn`. the default openvpn configuration file is set up to use us-midwest in PIA
- **Credentials**: we link a credential file into the container at build time, add your credentials to this file `deps/creds.x` and they will be copied in when you build the image. this should be a two lined file, first being your username, second your password. you can link this file in at runtime as well, just mount it to `/openvpn/creds.x`.
- **Running**: execute `make build_web` to build the container and `make run` to run the container with the proper run commands.
- **Accessing**: after the server is run, you can access the clutch frontend in your brower on port `9091`. the default user and pass are `admin` and `password` respectively.
